pub struct ManagedSettingsBindingClient(pub(crate) ManagedSettingsClient);Expand description
UniFFI wrapper for [ManagedSettingsClient].
The host application constructs one of these at boot, acquires a management profile from the
operating system’s Unified Endpoint Management channel, and pushes it in with
update_profile.
Tuple Fields
0: ManagedSettingsClientImplementations
Sourceimpl ManagedSettingsBindingClient
impl ManagedSettingsBindingClient
Sourcepub fn update_profile(&self, profile: Option<ManagementProfile>)
pub fn update_profile(&self, profile: Option<ManagementProfile>)
Replace the active profile. Clear the profile with None.
Sourcepub fn is_managed(&self, key: String) -> bool
pub fn is_managed(&self, key: String) -> bool
Returns true if key is present in the active profile.